@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (C) 2007-2009 Andrew Resch <andrewresch@gmail.com>
 #
@@ -7,8 +6,6 @@
 # See LICENSE for more details.
 #
 
-from __future__ import unicode_literals
-
 from deluge.plugins.init import PluginInitBase
 
 
@@ -17,7 +14,7 @@ class CorePlugin(PluginInitBase):
         from .core import Core as _pluginCls
 
         self._plugin_cls = _pluginCls
-        super(CorePlugin, self).__init__(plugin_name)
+        super().__init__(plugin_name)
 
 
 class GtkUIPlugin(PluginInitBase):
@@ -25,7 +22,7 @@ class GtkUIPlugin(PluginInitBase):
         from .gtkui import GtkUI as _pluginCls
 
         self._plugin_cls = _pluginCls
-        super(GtkUIPlugin, self).__init__(plugin_name)
+        super().__init__(plugin_name)
 
 
 class WebUIPlugin(PluginInitBase):
@@ -33,4 +30,4 @@ class WebUIPlugin(PluginInitBase):
         from .webui import WebUI as _pluginCls
 
         self._plugin_cls = _pluginCls
-        super(WebUIPlugin, self).__init__(plugin_name)
+        super().__init__(plugin_name)
