@@ -14,6 +14,7 @@
 torrent-label core plugin.
 adds a status field for tracker.
 """
+
 import logging
 import re
 
@@ -137,6 +138,7 @@ class Core(CorePluginBase):
         log.debug('post_torrent_remove')
         if torrent_id in self.torrent_labels:
             del self.torrent_labels[torrent_id]
+            self.config.save()
 
     # Utils #
     def clean_config(self):
@@ -181,7 +183,7 @@ class Core(CorePluginBase):
             RE_VALID.match(label_id), _('Invalid label, valid characters:[a-z0-9_-]')
         )
         check_input(label_id, _('Empty Label'))
-        check_input(not (label_id in self.labels), _('Label already exists'))
+        check_input(label_id not in self.labels, _('Label already exists'))
 
         self.labels[label_id] = dict(OPTIONS_DEFAULTS)
         self.config.save()
@@ -191,8 +193,7 @@ class Core(CorePluginBase):
         """remove a label"""
         check_input(label_id in self.labels, _('Unknown Label'))
         del self.labels[label_id]
-        self.clean_config()
-        self.config.save()
+        self.save_config()
 
     def _set_torrent_options(self, torrent_id, label_id):
         options = self.labels[label_id]
