@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (C) 2015 Calum Lind <calumlind@gmail.com>
 # Copyright (C) 2010 Pedro Algarvio <ufs@ufsoft.org>
@@ -8,17 +7,14 @@
 # See LICENSE for more details.
 #
 
-from __future__ import unicode_literals
-
 import logging
 import warnings
 
+from deluge.conftest import BaseTestCase
 from deluge.log import setup_logger
 
-from .basetest import BaseTestCase
 
-
-class LogTestCase(BaseTestCase):
+class TestLog(BaseTestCase):
     def set_up(self):
         setup_logger(logging.DEBUG)
 
@@ -32,7 +28,7 @@ class LogTestCase(BaseTestCase):
             # Cause all warnings to always be triggered.
             warnings.simplefilter('always')
             LOG.debug('foo')
-            self.assertEqual(w[-1].category, DeprecationWarning)
+            assert w[-1].category is DeprecationWarning
 
     # def test_twisted_error_log(self):
     #    from twisted.internet import defer
