@@ -6,7 +6,6 @@
 import os.path
 
 import pytest
-import pytest_twisted
 
 import deluge.component as component
 import deluge.ui.tracker_icons
@@ -28,7 +27,6 @@ class TestTrackerIcons(BaseTestCase):
     def tear_down(self):
         return component.shutdown()
 
-    @pytest_twisted.ensureDeferred
     async def test_get_deluge_png(self, mock_mkstemp):
         # Deluge has a png favicon link
         icon = TrackerIcon(common.get_test_data_file('deluge.png'))
@@ -36,7 +34,6 @@ class TestTrackerIcons(BaseTestCase):
         assert result == icon
         assert not os.path.isfile(mock_mkstemp[1])
 
-    @pytest_twisted.ensureDeferred
     async def test_get_google_ico(self):
         # Google doesn't have any icon links
         # So instead we'll grab its favicon.ico
@@ -44,14 +41,12 @@ class TestTrackerIcons(BaseTestCase):
         result = await self.icons.fetch('www.google.com')
         assert result == icon
 
-    @pytest_twisted.ensureDeferred
     async def test_get_google_ico_hebrew(self):
         """Test that Google.co.il page is read as UTF-8"""
         icon = TrackerIcon(common.get_test_data_file('google.ico'))
         result = await self.icons.fetch('www.google.co.il')
         assert result == icon
 
-    @pytest_twisted.ensureDeferred
     async def test_get_google_ico_with_redirect(self):
         # google.com redirects to www.google.com
         icon = TrackerIcon(common.get_test_data_file('google.ico'))
@@ -59,19 +54,16 @@ class TestTrackerIcons(BaseTestCase):
         assert result == icon
 
     @pytest.mark.skip(reason='Site removed favicon, new SNI test will be needed')
-    @pytest_twisted.ensureDeferred
     async def test_get_seo_svg_with_sni(self):
         # seo using certificates with SNI support only
         icon = TrackerIcon(common.get_test_data_file('seo.svg'))
         result = await self.icons.fetch('www.seo.com')
         assert result == icon
 
-    @pytest_twisted.ensureDeferred
     async def test_get_empty_string_tracker(self):
         result = await self.icons.fetch('')
         assert result is None
 
-    @pytest_twisted.ensureDeferred
     async def test_invalid_host(self, mock_mkstemp):
         """Test that TrackerIcon can handle invalid hostname"""
         result = await self.icons.fetch('deluge.example.com')
