@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (C) 2009-2010 Damien Churchill <damoxc@gmail.com>
 #
@@ -7,14 +6,13 @@
 # See LICENSE for more details.
 #
 
-from __future__ import unicode_literals
-
 import fnmatch
 import json
 import logging
 import mimetypes
 import os
 import tempfile
+from pathlib import Path
 
 from twisted.application import internet, service
 from twisted.internet import defer, reactor
@@ -22,13 +20,13 @@ from twisted.web import http, resource, server, static
 from twisted.web.resource import EncodingResourceWrapper
 
 from deluge import common, component, configmanager
-from deluge.common import is_ipv6
-from deluge.core.rpcserver import check_ssl_keys
-from deluge.crypto_utils import get_context_factory
+from deluge.common import AUTH_LEVEL_DEFAULT, is_ipv6
+from deluge.crypto_utils import check_ssl_keys, get_context_factory
+from deluge.error import NotAuthorizedError
 from deluge.i18n import set_language, setup_translation
 from deluge.ui.tracker_icons import TrackerIcons
 from deluge.ui.web.auth import Auth
-from deluge.ui.web.common import Template
+from deluge.ui.web.common import Template, _
 from deluge.ui.web.json_api import JSON, WebApi, WebUtils
 from deluge.ui.web.pluginmanager import PluginManager
 
@@ -77,6 +75,20 @@ def rpath(*paths):
     return common.resource_filename('deluge.ui.web', os.path.join(*paths))
 
 
+def absolute_base_url(base):
+    """Returns base as absolute URL for links"""
+    if not base:
+        base = '/'
+
+    if not base.startswith('/'):
+        base = '/' + base
+
+    if not base.endswith('/'):
+        base += '/'
+
+    return base
+
+
 class GetText(resource.Resource):
     def render(self, request):
         request.setHeader(b'content-type', b'text/javascript; encoding=utf-8')
@@ -131,14 +143,12 @@ class Upload(resource.Resource):
 
         request.setHeader(b'content-type', b'text/html')
         request.setResponseCode(http.OK)
-        return json.dumps({'success': bool(filenames), 'files': filenames}).encode(
-            'utf8'
-        )
+        return json.dumps({'success': bool(filenames), 'files': filenames}).encode()
 
 
 class Render(resource.Resource):
     def __init__(self):
-        resource.Resource.__init__(self)
+        super().__init__()
         # Make a list of all the template files to check requests against.
         self.template_files = fnmatch.filter(os.listdir(rpath('render')), '*.html')
 
@@ -167,14 +177,15 @@ class Render(resource.Resource):
 
 class Tracker(resource.Resource):
     def __init__(self):
-        resource.Resource.__init__(self)
+        super().__init__()
         try:
             self.tracker_icons = component.get('TrackerIcons')
         except KeyError:
             self.tracker_icons = TrackerIcons()
 
-    def getChild(self, path, request):  # NOQA: N802
-        request.tracker_name = path
+    def getChild(self, path: bytes, request):  # NOQA: N802
+        # Ensure tracker name only to prevent path traversal.
+        request.tracker_name = os.path.basename(path.decode())
         return self
 
     def on_got_icon(self, icon, request):
@@ -182,7 +193,7 @@ class Tracker(resource.Resource):
             request.setHeader(
                 b'cache-control', b'public, must-revalidate, max-age=86400'
             )
-            request.setHeader(b'content-type', icon.get_mimetype().encode('utf8'))
+            request.setHeader(b'content-type', icon.get_mimetype().encode())
             request.setResponseCode(http.OK)
             request.write(icon.get_data())
             request.finish()
@@ -191,8 +202,22 @@ class Tracker(resource.Resource):
             request.finish()
 
     def render(self, request):
-        d = self.tracker_icons.fetch(request.tracker_name.decode())
-        d.addCallback(self.on_got_icon, request)
+        tracker_icon = self.tracker_icons.get(request.tracker_name)
+        if tracker_icon:
+            self.on_got_icon(tracker_icon, request)
+            return server.NOT_DONE_YET
+
+        # Tracker endpoint is secured to avoid exploits when downloading icons.
+        try:
+            component.get('Auth').check_request(request, level=AUTH_LEVEL_DEFAULT)
+        except NotAuthorizedError:
+            log.warning('Auth required to download tracker icon.')
+            request.setResponseCode(http.UNAUTHORIZED)
+            request.finish()
+        else:
+            self.tracker_icons.fetch(request.tracker_name).addCallback(
+                self.on_got_icon, request
+            )
         return server.NOT_DONE_YET
 
 
@@ -202,7 +227,9 @@ class Flag(resource.Resource):
         return self
 
     def render(self, request):
-        flag = request.country.decode('utf-8').lower() + '.png'
+        country = request.country.decode().lower()
+        # Ensure filename only, to prevent path traversal.
+        flag = os.path.basename(f'{country}.png')
         path = ('ui', 'data', 'pixmaps', 'flags', flag)
         filename = common.resource_filename('deluge', os.path.join(*path))
         if os.path.exists(filename):
@@ -376,7 +403,7 @@ class ScriptResource(resource.Resource, component.Component):
 
                     order_file = os.path.join(root, '.order')
                     if os.path.isfile(order_file):
-                        with open(order_file, 'r') as _file:
+                        with open(order_file) as _file:
                             for line in _file:
                                 if line.startswith('+ '):
                                     order_filename = line.split()[1]
@@ -424,8 +451,18 @@ class ScriptResource(resource.Resource, component.Component):
                     filepath = filepath[0]
 
                 path = filepath + lookup_path[len(pattern) :]
+                path = os.path.abspath(path)
+
+                if not os.path.commonpath([path, filepath]) == filepath:
+                    log.warning(
+                        'Script path %s traverses out of common dir %s',
+                        path,
+                        filepath,
+                    )
+                    continue
 
                 if not os.path.isfile(path):
+                    log.warning('Unable to serve script which does not exist: %s', path)
                     continue
 
                 log.debug('Serving path: %s', path)
@@ -451,7 +488,6 @@ class Themes(static.File):
 
 
 class TopLevel(resource.Resource):
-
     __stylesheets = [
         'css/ext-all-notheme.css',
         'css/ext-extensions.css',
@@ -459,7 +495,7 @@ class TopLevel(resource.Resource):
     ]
 
     def __init__(self):
-        resource.Resource.__init__(self)
+        super().__init__()
 
         self.putChild(b'css', LookupResource('Css', rpath('css')))
         if os.path.isfile(rpath('js', 'gettext.js')):
@@ -479,7 +515,8 @@ class TopLevel(resource.Resource):
         self.putChild(
             b'ui_images',
             LookupResource(
-                'UI_Images', common.resource_filename('deluge.ui.data', 'pixmaps')
+                'UI_Images',
+                common.resource_filename('deluge.ui', os.path.join('data', 'pixmaps')),
             ),
         )
 
@@ -531,15 +568,28 @@ class TopLevel(resource.Resource):
         self.putChild(b'themes', Themes(rpath('themes')))
         self.putChild(b'tracker', Tracker())
 
-        theme = component.get('DelugeWeb').config['theme']
-        if not os.path.isfile(rpath('themes', 'css', 'xtheme-%s.css' % theme)):
-            theme = CONFIG_DEFAULTS.get('theme')
-        self.__stylesheets.insert(1, 'themes/css/xtheme-%s.css' % theme)
-
     @property
     def stylesheets(self):
         return self.__stylesheets
 
+    def get_themes(self):
+        themes_dir = Path(rpath('themes', 'css'))
+        themes = [
+            theme.stem.split('xtheme-')[1] for theme in themes_dir.glob('xtheme-*.css')
+        ]
+        themes = [(theme, _(theme.capitalize())) for theme in themes]
+        return themes
+
+    def set_theme(self, theme: str):
+        if not os.path.isfile(rpath('themes', 'css', f'xtheme-{theme}.css')):
+            theme = CONFIG_DEFAULTS.get('theme')
+        self.__theme = f'themes/css/xtheme-{theme}.css'
+
+        # Only one xtheme CSS, ordered last to override other styles.
+        if 'xtheme-' in self.stylesheets[-1]:
+            self.__stylesheets.pop()
+        self.__stylesheets.append(self.__theme)
+
     def add_script(self, script):
         """
         Adds a script to the server so it is included in the <head> element
@@ -562,30 +612,21 @@ class TopLevel(resource.Resource):
         self.__scripts.remove(script)
         self.__debug_scripts.remove(script)
 
-    def getChild(self, path, request):  # NOQA: N802
-        if not path:
-            return self
-        else:
-            return resource.Resource.getChild(self, path, request)
-
     def getChildWithDefault(self, path, request):  # NOQA: N802
         # Calculate the request base
-        header = request.getHeader(b'x-deluge-base')
-        base = header.decode('utf-8') if header else component.get('DelugeWeb').base
+        header = request.getHeader('x-deluge-base')
+        config_base = component.get('DelugeWeb').base
+        base = header if header else config_base
 
-        # validate the base parameter
-        if not base:
-            base = '/'
+        first_request = not hasattr(request, 'base')
+        request.base = absolute_base_url(base).encode()
 
-        if base[0] != '/':
-            base = '/' + base
+        base_resource = first_request and path.decode() == config_base.strip('/')
 
-        if base[-1] != '/':
-            base += '/'
+        if not path or base_resource:
+            return self
 
-        request.base = base.encode('utf-8')
-
-        return resource.Resource.getChildWithDefault(self, path, request)
+        return super().getChildWithDefault(path, request)
 
     def render(self, request):
         uri_true = ('true', 'yes', 'on', '1')
@@ -657,7 +698,7 @@ class DelugeWeb(component.Component):
                 reactor). If False shares the process and twisted reactor from WebUI plugin or tests.
 
         """
-        component.Component.__init__(self, 'DelugeWeb', depend=['Web'])
+        super().__init__('DelugeWeb', depend=['Web'])
         self.config = configmanager.ConfigManager(
             'web.conf', defaults=CONFIG_DEFAULTS, file_version=2
         )
@@ -684,9 +725,7 @@ class DelugeWeb(component.Component):
             elif options.no_ssl:
                 self.https = False
 
-        if self.base != '/':
-            # Strip away slashes and serve on the base path as well as root path
-            self.top_level.putChild(self.base.strip('/'), self.top_level)
+        self.top_level.set_theme(self.config['theme'])
 
         setup_translation()
 
@@ -746,8 +785,8 @@ class DelugeWeb(component.Component):
     def start_normal(self):
         self.socket = reactor.listenTCP(self.port, self.site, interface=self.interface)
         ip = self.socket.getHost().host
-        ip = '[%s]' % ip if is_ipv6(ip) else ip
-        log.info('Serving at http://%s:%s%s', ip, self.port, self.base)
+        ip = f'[{ip}]' if is_ipv6(ip) else ip
+        log.info(f'Serving at http://{ip}:{self.port}{self.base}')
 
     def start_ssl(self):
         check_ssl_keys()
@@ -763,8 +802,8 @@ class DelugeWeb(component.Component):
             interface=self.interface,
         )
         ip = self.socket.getHost().host
-        ip = '[%s]' % ip if is_ipv6(ip) else ip
-        log.info('Serving at https://%s:%s%s', ip, self.port, self.base)
+        ip = f'[{ip}]' if is_ipv6(ip) else ip
+        log.info(f'Serving at https://{ip}:{self.port}{self.base}')
 
     def stop(self):
         log.info('Shutting down webserver')
@@ -794,6 +833,12 @@ class DelugeWeb(component.Component):
         config['language'] = CONFIG_DEFAULTS['language']
         return config
 
+    def get_themes(self):
+        return self.top_level.get_themes()
+
+    def set_theme(self, theme: str):
+        self.top_level.set_theme(theme)
+
 
 if __name__ == '__builtin__':
     deluge_web = DelugeWeb()
